function varargout = mmpannotation(varargin)
% mmpannotation MATLAB code for mmpannotation.fig
%      mmpannotation, by itself, creates a new mmpannotation or raises the existing
%      singleton*.
%
%      H = mmpannotation returns the handle to a new mmpannotation or the handle to
%      the existing singleton*.
%
%      mmpannotation('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in mmpannotation.M with the given input arguments.
%
%      mmpannotation('Property','Value',...) creates a new mmpannotation or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before mmpannotation_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to mmpannotation_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help mmpannotation

% Last Modified by GUIDE v2.5 05-Feb-2017 16:23:41

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @mmpannotation_OpeningFcn, ...
                   'gui_OutputFcn',  @mmpannotation_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before mmpannotation is made visible.
function mmpannotation_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to mmpannotation (see VARARGIN)

% Choose default command line output for mmpannotation
handles.output = hObject;
[num,text,raw]=xlsread('term.xlsx');
set(handles.listbox1,'str',text(1,2:end));
handles.termact=num;
handles.termname=raw(2:end,1);

load('reg_gene_expression_all.mat');
set(handles.listbox2,'str',use_region_names);

handles.regexp=region_exp;
handles.genenames=genename;
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes mmpannotation wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = mmpannotation_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on selection change in listbox1.
function listbox1_Callback(hObject, eventdata, handles)
% hObject    handle to listbox1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = cellstr(get(hObject,'String')) returns listbox1 contents as cell array
%        contents{get(hObject,'Value')} returns selected item from listbox1
value=get(hObject,'Value');
 [a,b]=sort(handles.termact(:,value),'descend');
% 
col_name{1}='Term Name';
col_name{2}='Activation Percentiles';
term_act=[handles.termname(b),cellstr(num2str(handles.termact(b,value)))];
set(handles.uitable1,'ColumnName',col_name,'data',term_act,'ColumnEditable',true);
% --- Executes during object creation, after setting all properties.
function listbox1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to listbox1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in listbox2.
function listbox2_Callback(hObject, eventdata, handles)
% hObject    handle to listbox2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = cellstr(get(hObject,'String')) returns listbox2 contents as cell array
%        contents{get(hObject,'Value')} returns selected item from listbox2
value=get(hObject,'Value');
 [a,b]=sort(handles.regexp(value,:),'descend');
% 
col_name{1}='Gene Name';
col_name{2}='Normalized Expression';
gene_act=[handles.genenames(b),cellstr(num2str(handles.regexp(value,b)'))];
set(handles.uitable2,'ColumnName',col_name,'data',gene_act,'ColumnEditable',true);

% --- Executes during object creation, after setting all properties.
function listbox2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to listbox2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
